@@ -16,34 +16,44 @@
  *
  * @global string $wp_version
  */
-$wp_version = '6.4.3';
+$wp_version = '6.8.2';
 
 /**
  * Holds the WordPress DB revision, increments when changes are made to the WordPress DB schema.
  *
  * @global int $wp_db_version
  */
-$wp_db_version = 56657;
+$wp_db_version = 60421;
 
 /**
  * Holds the TinyMCE version.
  *
  * @global string $tinymce_version
  */
-$tinymce_version = '49110-20201110';
+$tinymce_version = '49110-20250317';
 
 /**
  * Holds the required PHP version.
  *
  * @global string $required_php_version
  */
-$required_php_version = '7.0.0';
+$required_php_version = '7.2.24';
+
+/**
+ * Holds the names of required PHP extensions.
+ *
+ * @global string[] $required_php_extensions
+ */
+$required_php_extensions = array(
+	'json',
+	'hash',
+);
 
 /**
  * Holds the required MySQL version.
  *
  * @global string $required_mysql_version
  */
-$required_mysql_version = '5.0';
+$required_mysql_version = '5.5.5';
 
 $wp_local_package = 'ja';
